@@ -1,10 +1,8 @@
 from django.contrib import messages
 from django.contrib.admin.utils import quote
-from django.contrib.auth.decorators import login_required
 from django.shortcuts import redirect
 from django.template.response import TemplateResponse
 from django.urls import include, path, reverse
-from django.utils.decorators import method_decorator
 from django.utils.translation import gettext_lazy as _
 from wagtail.admin import messages as wagtail_messages
 from wagtail.contrib.modeladmin.helpers import AdminURLHelper, ButtonHelper
@@ -144,7 +142,7 @@ class FormModelAdmin(ModelAdmin):
     list_filter = None
     menu_label = _(get_setting("ADMIN_MENU_LABEL"))
     menu_order = get_setting("ADMIN_MENU_ORDER")
-    menu_icon = "icon icon-form"
+    menu_icon = "form"
     search_fields = ("title", "slug")
     button_helper_class = FormButtonHelper
     inspect_view_class = InspectFormView
@@ -223,7 +221,8 @@ def process_form(page, request, *args, **kwargs):
                     )
 
                 # redirect to the page defined in the form
-                # or the current page as a fallback - this will avoid refreshing and submitting again
+                # or the current page as a fallback - this will avoid refreshing
+                # and submitting again
                 redirect_page = form_def.post_redirect_page or page
 
                 return redirect(redirect_page.get_url(request), context=context)
